==> bogofilter_1.2.5.orig.tar.xz: bogofilter-1.2.5/src/chUnicodeTo866.h <==
/* Unicode.h */
/* ⠡ pp CP866->Unicode */
int UnicodeTable[256]= {
    0     , 0x01  , 0x02  , 0x03  , 0x04  , 0x05  , 0x06  , 0x07  , 0x08  , 0x09  , 0x0A  , 0x0B  , 0x0C  , 0x0D  , 0x0E  , 0x0F  , 
    0x10  , 0x11  , 0x12  , 0x13  , 0xB6  , 0xA7  , 0x16  , 0x17  , 0x18  , 0x19  , 0x1A  , 0x1B  , 0x1C  , 0x1D  , 0x1E  , 0x1F  , 
    0x20  , 0x21  , 0x22  , 0x23  , 0x24  , 0x25  , 0x26  , 0x27  , 0x28  , 0x29  , 0x2A  , 0x2B  , 0x2C  , 0x2D  , 0x2E  , 0x2F  , 
    0x30  , 0x31  , 0x32  , 0x33  , 0x34  , 0x35  , 0x36  , 0x37  , 0x38  , 0x39  , 0x3A  , 0x3B  , 0x3C  , 0x3D  , 0x3E  , 0x3F  , 
    0x40  , 0x41  , 0x42  , 0x43  , 0x44  , 0x45  , 0x46  , 0x47  , 0x48  , 0x49  , 0x4A  , 0x4B  , 0x4C  , 0x4D  , 0x4E  , 0x4F  , 
    0x50  , 0x51  , 0x52  , 0x53  , 0x54  , 0x55  , 0x56  , 0x57  , 0x58  , 0x59  , 0x5A  , 0x5B  , 0x5C  , 0x5D  , 0x5E  , 0x5F  , 
    0x60  , 0x61  , 0x62  , 0x63  , 0x64  , 0x65  , 0x66  , 0x67  , 0x68  , 0x69  , 0x6A  , 0x6B  , 0x6C  , 0x6D  , 0x6E  , 0x6F  , 
    0x70  , 0x71  , 0x72  , 0x73  , 0x74  , 0x75  , 0x76  , 0x77  , 0x78  , 0x79  , 0x7A  , 0x7B  , 0x7C  , 0x7D  , 0x7E  , 0x7F  , 
    0x410 , 0x411 , 0x412 , 0x413 , 0x414 , 0x415 , 0x416 , 0x417 , 0x418 , 0x419 , 0x41A , 0x41B , 0x41C , 0x41D , 0x41E , 0x41F , 
    0x420 , 0x421 , 0x422 , 0x423 , 0x424 , 0x425 , 0x426 , 0x427 , 0x428 , 0x429 , 0x42A , 0x42B , 0x42C , 0x42D , 0x42E , 0x42F , 
    0x430 , 0x431 , 0x432 , 0x433 , 0x434 , 0x435 , 0x436 , 0x437 , 0x438 , 0x439 , 0x43A , 0x43B , 0x43C , 0x43D , 0x43E , 0x43F , 
    0x2591, 0x2592, 0x2593, 0x2502, 0x2524, 0x2561, 0x2562, 0x2556, 0x2555, 0x2563, 0x2551, 0x2557, 0x255D, 0x255C, 0x255B, 0x2510, 
    0x2514, 0x2534, 0x252C, 0x251C, 0x2500, 0x253C, 0x255E, 0x255F, 0x255A, 0x2554, 0x2569, 0x2566, 0x2560, 0x2550, 0x256C, 0x2567, 
    0x2568, 0x2564, 0x2565, 0x2559, 0x2558, 0x2552, 0x2553, 0x256B, 0x256A, 0x2518, 0x250C, 0x2588, 0x2584, 0x258C, 0x2590, 0x2580, 
    0x440 , 0x441 , 0x442 , 0x443 , 0x444 , 0x445 , 0x446 , 0x447 , 0x448 , 0x449 , 0x44A , 0x44B , 0x44C , 0x44D , 0x44E , 0x44F , 
    0x401 , 0x451 , 0x404 , 0x454 , 0x407 , 0x457 , 0x40E , 0x45E , 0xB0  , 0x2219, 0xB7  , 0x221A, 0x2116, 0xA4  , 0x25A0, 0xA0  
};

/* Html &-sequences */
typedef unsigned char uchar;

struct htmlSeq
{
    const char *sht;
    uchar cht;
};

const struct htmlSeq html_code[] =
{
    {"nbsp",    32}, 
    {"#191",   191}, {"Agrave", 192}, {"Aacute", 193},
    {"Acirc",  194}, {"Atilde", 195}, {"Auml",   196},
    {"Aring",  197}, {"AElig",  198}, {"Ccedil", 199},
    {"Egrave", 200}, {"Eacute", 201}, {"Ecirc",  202},
    {"Euml",   203}, {"Igrave", 204}, {"Iacute", 205},
    {"Icirc",  206}, {"Iuml",   207}, {"ETH",    208},
    {"Ntilde", 209}, {"Ograve", 210}, {"Oacute", 211},
    {"Ocirc",  212}, {"Otilde", 213}, {"Ouml",   214},
    {"#215",   215}, {"Oslash", 216}, {"Ugrave", 217},
    {"Uacute", 218}, {"Ucirc",  219}, {"Uuml",   220},
    {"Yacute", 221}, {"THORN",  222}, {"szlig",  223},
    {"agrave", 224}, {"aacute", 225}, {"acirc",  226},
    {"atilde", 227}, {"auml",   228}, {"aring",  229},
    {"aelig",  230}, {"ccedil", 231}, {"egrave", 232},
    {"eacute", 233}, {"ecirc",  234}, {"euml",   235},
    {"igrave", 236}, {"iacute", 237}, {"icirc",  238},
    {"iuml",   239}, {"eth",    240}, {"ntilde", 241},
    {"ograve", 242}, {"oacute", 243}, {"ocirc",  244},
    {"otilde", 245}, {"ouml",   246}, {"#247",   247},
    {"oslash", 248}, {"ugrave", 249}, {"uacute", 250},
    {"ucirc",  251}, {"uuml",   252}, {"yacute", 253},
    {"thorn",  254}, {"yuml",   255}, { NULL,      0}
};

==> bogofilter-1.3.0.rc1.tar.xz: bogofilter-1.3.0.rc1/src/chUnicodeTo866.h <==
/* Unicode.h */
/* таблица пеpекодиpовки CP866->Unicode,
 * but note this comment has been converted to UTF-8 on 2025-03-23 */
int UnicodeTable[256]= {
    0x00  , 0x01  , 0x02  , 0x03  , 0x04  , 0x05  , 0x06  , 0x07  , 0x08  , 0x09  , 0x0A  , 0x0B  , 0x0C  , 0x0D  , 0x0E  , 0x0F  ,
    0x10  , 0x11  , 0x12  , 0x13  , 0xB6  , 0xA7  , 0x16  , 0x17  , 0x18  , 0x19  , 0x1A  , 0x1B  , 0x1C  , 0x1D  , 0x1E  , 0x1F  ,
    0x20  , 0x21  , 0x22  , 0x23  , 0x24  , 0x25  , 0x26  , 0x27  , 0x28  , 0x29  , 0x2A  , 0x2B  , 0x2C  , 0x2D  , 0x2E  , 0x2F  ,
    0x30  , 0x31  , 0x32  , 0x33  , 0x34  , 0x35  , 0x36  , 0x37  , 0x38  , 0x39  , 0x3A  , 0x3B  , 0x3C  , 0x3D  , 0x3E  , 0x3F  ,
    0x40  , 0x41  , 0x42  , 0x43  , 0x44  , 0x45  , 0x46  , 0x47  , 0x48  , 0x49  , 0x4A  , 0x4B  , 0x4C  , 0x4D  , 0x4E  , 0x4F  ,
    0x50  , 0x51  , 0x52  , 0x53  , 0x54  , 0x55  , 0x56  , 0x57  , 0x58  , 0x59  , 0x5A  , 0x5B  , 0x5C  , 0x5D  , 0x5E  , 0x5F  ,
    0x60  , 0x61  , 0x62  , 0x63  , 0x64  , 0x65  , 0x66  , 0x67  , 0x68  , 0x69  , 0x6A  , 0x6B  , 0x6C  , 0x6D  , 0x6E  , 0x6F  ,
    0x70  , 0x71  , 0x72  , 0x73  , 0x74  , 0x75  , 0x76  , 0x77  , 0x78  , 0x79  , 0x7A  , 0x7B  , 0x7C  , 0x7D  , 0x7E  , 0x7F  ,
    0x410 , 0x411 , 0x412 , 0x413 , 0x414 , 0x415 , 0x416 , 0x417 , 0x418 , 0x419 , 0x41A , 0x41B , 0x41C , 0x41D , 0x41E , 0x41F ,
    0x420 , 0x421 , 0x422 , 0x423 , 0x424 , 0x425 , 0x426 , 0x427 , 0x428 , 0x429 , 0x42A , 0x42B , 0x42C , 0x42D , 0x42E , 0x42F ,
    0x430 , 0x431 , 0x432 , 0x433 , 0x434 , 0x435 , 0x436 , 0x437 , 0x438 , 0x439 , 0x43A , 0x43B , 0x43C , 0x43D , 0x43E , 0x43F ,
    0x2591, 0x2592, 0x2593, 0x2502, 0x2524, 0x2561, 0x2562, 0x2556, 0x2555, 0x2563, 0x2551, 0x2557, 0x255D, 0x255C, 0x255B, 0x2510,
    0x2514, 0x2534, 0x252C, 0x251C, 0x2500, 0x253C, 0x255E, 0x255F, 0x255A, 0x2554, 0x2569, 0x2566, 0x2560, 0x2550, 0x256C, 0x2567,
    0x2568, 0x2564, 0x2565, 0x2559, 0x2558, 0x2552, 0x2553, 0x256B, 0x256A, 0x2518, 0x250C, 0x2588, 0x2584, 0x258C, 0x2590, 0x2580,
    0x440 , 0x441 , 0x442 , 0x443 , 0x444 , 0x445 , 0x446 , 0x447 , 0x448 , 0x449 , 0x44A , 0x44B , 0x44C , 0x44D , 0x44E , 0x44F ,
    0x401 , 0x451 , 0x404 , 0x454 , 0x407 , 0x457 , 0x40E , 0x45E , 0xB0  , 0x2219, 0xB7  , 0x221A, 0x2116, 0xA4  , 0x25A0, 0xA0
};

/* Html &-sequences */
typedef unsigned char uchar;

struct htmlSeq
{
    const char *sht;
    uchar cht;
};

const struct htmlSeq html_code[] =
{
    {"nbsp",    32}, 
    {"#191",   191}, {"Agrave", 192}, {"Aacute", 193},
    {"Acirc",  194}, {"Atilde", 195}, {"Auml",   196},
    {"Aring",  197}, {"AElig",  198}, {"Ccedil", 199},
    {"Egrave", 200}, {"Eacute", 201}, {"Ecirc",  202},
    {"Euml",   203}, {"Igrave", 204}, {"Iacute", 205},
    {"Icirc",  206}, {"Iuml",   207}, {"ETH",    208},
    {"Ntilde", 209}, {"Ograve", 210}, {"Oacute", 211},
    {"Ocirc",  212}, {"Otilde", 213}, {"Ouml",   214},
    {"#215",   215}, {"Oslash", 216}, {"Ugrave", 217},
    {"Uacute", 218}, {"Ucirc",  219}, {"Uuml",   220},
    {"Yacute", 221}, {"THORN",  222}, {"szlig",  223},
    {"agrave", 224}, {"aacute", 225}, {"acirc",  226},
    {"atilde", 227}, {"auml",   228}, {"aring",  229},
    {"aelig",  230}, {"ccedil", 231}, {"egrave", 232},
    {"eacute", 233}, {"ecirc",  234}, {"euml",   235},
    {"igrave", 236}, {"iacute", 237}, {"icirc",  238},
    {"iuml",   239}, {"eth",    240}, {"ntilde", 241},
    {"ograve", 242}, {"oacute", 243}, {"ocirc",  244},
    {"otilde", 245}, {"ouml",   246}, {"#247",   247},
    {"oslash", 248}, {"ugrave", 249}, {"uacute", 250},
    {"ucirc",  251}, {"uuml",   252}, {"yacute", 253},
    {"thorn",  254}, {"yuml",   255}, { NULL,      0}
};
